pub struct And<A, B>(pub A, pub B);Expand description
Compose two validators with AND semantics.
Both validators must pass for the combined validator to pass. The score is the minimum of the two validators’ scores.
Tuple Fields
0: A1: BTrait Implementations
impl<A: Copy, B: Copy> Copy for And<A, B>